# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class SiteConnection(pulumi.CustomResource):
    """
    Manages a V2 Neutron IPSec site connection resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, admin_state_up=None, description=None, dpds=None, ikepolicy_id=None, initiator=None, ipsecpolicy_id=None, local_ep_group_id=None, local_id=None, mtu=None, name=None, peer_address=None, peer_cidrs=None, peer_ep_group_id=None, peer_id=None, psk=None, region=None, tenant_id=None, value_specs=None, vpnservice_id=None):
        """Create a SiteConnection resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if admin_state_up and not isinstance(admin_state_up, bool):
            raise TypeError('Expected property admin_state_up to be a bool')
        __self__.admin_state_up = admin_state_up
        """
        The administrative state of the resource. Can either be up(true) or down(false).
        Changing this updates the administrative state of the existing connection.
        """
        __props__['adminStateUp'] = admin_state_up

        if description and not isinstance(description, basestring):
            raise TypeError('Expected property description to be a basestring')
        __self__.description = description
        """
        The human-readable description for the connection.
        Changing this updates the description of the existing connection.
        """
        __props__['description'] = description

        if dpds and not isinstance(dpds, list):
            raise TypeError('Expected property dpds to be a list')
        __self__.dpds = dpds
        """
        A dictionary with dead peer detection (DPD) protocol controls.
        - `action` - (Optional) The dead peer detection (DPD) action.
        A valid value is clear, hold, restart, disabled, or restart-by-peer.
        Default value is hold.
        """
        __props__['dpds'] = dpds

        if not ikepolicy_id:
            raise TypeError('Missing required property ikepolicy_id')
        elif not isinstance(ikepolicy_id, basestring):
            raise TypeError('Expected property ikepolicy_id to be a basestring')
        __self__.ikepolicy_id = ikepolicy_id
        """
        The ID of the IKE policy. Changing this creates a new connection.
        """
        __props__['ikepolicyId'] = ikepolicy_id

        if initiator and not isinstance(initiator, basestring):
            raise TypeError('Expected property initiator to be a basestring')
        __self__.initiator = initiator
        """
        A valid value is response-only or bi-directional. Default is bi-directional.
        """
        __props__['initiator'] = initiator

        if not ipsecpolicy_id:
            raise TypeError('Missing required property ipsecpolicy_id')
        elif not isinstance(ipsecpolicy_id, basestring):
            raise TypeError('Expected property ipsecpolicy_id to be a basestring')
        __self__.ipsecpolicy_id = ipsecpolicy_id
        """
        The ID of the IPsec policy. Changing this creates a new connection.
        """
        __props__['ipsecpolicyId'] = ipsecpolicy_id

        if local_ep_group_id and not isinstance(local_ep_group_id, basestring):
            raise TypeError('Expected property local_ep_group_id to be a basestring')
        __self__.local_ep_group_id = local_ep_group_id
        """
        The ID for the endpoint group that contains private subnets for the local side of the connection.
        You must specify this parameter with the peer_ep_group_id parameter unless
        in backward- compatible mode where peer_cidrs is provided with a subnet_id for the VPN service.
        Changing this updates the existing connection.
        """
        __props__['localEpGroupId'] = local_ep_group_id

        if local_id and not isinstance(local_id, basestring):
            raise TypeError('Expected property local_id to be a basestring')
        __self__.local_id = local_id
        """
        An ID to be used instead of the external IP address for a virtual router used in traffic between instances on different networks in east-west traffic.
        Most often, local ID would be domain name, email address, etc.
        If this is not configured then the external IP address will be used as the ID.
        """
        __props__['localId'] = local_id

        if mtu and not isinstance(mtu, int):
            raise TypeError('Expected property mtu to be a int')
        __self__.mtu = mtu
        """
        The maximum transmission unit (MTU) value to address fragmentation.
        Minimum value is 68 for IPv4, and 1280 for IPv6.
        """
        __props__['mtu'] = mtu

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        The name of the connection. Changing this updates the name of
        the existing connection.
        """
        __props__['name'] = name

        if not peer_address:
            raise TypeError('Missing required property peer_address')
        elif not isinstance(peer_address, basestring):
            raise TypeError('Expected property peer_address to be a basestring')
        __self__.peer_address = peer_address
        """
        The peer gateway public IPv4 or IPv6 address or FQDN.
        """
        __props__['peerAddress'] = peer_address

        if peer_cidrs and not isinstance(peer_cidrs, list):
            raise TypeError('Expected property peer_cidrs to be a list')
        __self__.peer_cidrs = peer_cidrs
        """
        Unique list of valid peer private CIDRs in the form < net_address > / < prefix > .
        """
        __props__['peerCidrs'] = peer_cidrs

        if peer_ep_group_id and not isinstance(peer_ep_group_id, basestring):
            raise TypeError('Expected property peer_ep_group_id to be a basestring')
        __self__.peer_ep_group_id = peer_ep_group_id
        """
        The ID for the endpoint group that contains private CIDRs in the form < net_address > / < prefix > for the peer side of the connection.
        You must specify this parameter with the local_ep_group_id parameter unless in backward-compatible mode
        where peer_cidrs is provided with a subnet_id for the VPN service.
        """
        __props__['peerEpGroupId'] = peer_ep_group_id

        if not peer_id:
            raise TypeError('Missing required property peer_id')
        elif not isinstance(peer_id, basestring):
            raise TypeError('Expected property peer_id to be a basestring')
        __self__.peer_id = peer_id
        """
        The peer router identity for authentication. A valid value is an IPv4 address, IPv6 address, e-mail address, key ID, or FQDN.
        Typically, this value matches the peer_address value.
        Changing this updates the existing policy.
        """
        __props__['peerId'] = peer_id

        if not psk:
            raise TypeError('Missing required property psk')
        elif not isinstance(psk, basestring):
            raise TypeError('Expected property psk to be a basestring')
        __self__.psk = psk
        """
        The pre-shared key. A valid value is any string.
        """
        __props__['psk'] = psk

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create an IPSec site connection. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        site connection.
        """
        __props__['region'] = region

        if tenant_id and not isinstance(tenant_id, basestring):
            raise TypeError('Expected property tenant_id to be a basestring')
        __self__.tenant_id = tenant_id
        """
        The owner of the connection. Required if admin wants to
        create a connection for another project. Changing this creates a new connection.
        """
        __props__['tenantId'] = tenant_id

        if value_specs and not isinstance(value_specs, dict):
            raise TypeError('Expected property value_specs to be a dict')
        __self__.value_specs = value_specs
        """
        Map of additional options.
        """
        __props__['valueSpecs'] = value_specs

        if not vpnservice_id:
            raise TypeError('Missing required property vpnservice_id')
        elif not isinstance(vpnservice_id, basestring):
            raise TypeError('Expected property vpnservice_id to be a basestring')
        __self__.vpnservice_id = vpnservice_id
        """
        The ID of the VPN service. Changing this creates a new connection.
        """
        __props__['vpnserviceId'] = vpnservice_id

        super(SiteConnection, __self__).__init__(
            'openstack:vpnaas/siteConnection:SiteConnection',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'adminStateUp' in outs:
            self.admin_state_up = outs['adminStateUp']
        if 'description' in outs:
            self.description = outs['description']
        if 'dpds' in outs:
            self.dpds = outs['dpds']
        if 'ikepolicyId' in outs:
            self.ikepolicy_id = outs['ikepolicyId']
        if 'initiator' in outs:
            self.initiator = outs['initiator']
        if 'ipsecpolicyId' in outs:
            self.ipsecpolicy_id = outs['ipsecpolicyId']
        if 'localEpGroupId' in outs:
            self.local_ep_group_id = outs['localEpGroupId']
        if 'localId' in outs:
            self.local_id = outs['localId']
        if 'mtu' in outs:
            self.mtu = outs['mtu']
        if 'name' in outs:
            self.name = outs['name']
        if 'peerAddress' in outs:
            self.peer_address = outs['peerAddress']
        if 'peerCidrs' in outs:
            self.peer_cidrs = outs['peerCidrs']
        if 'peerEpGroupId' in outs:
            self.peer_ep_group_id = outs['peerEpGroupId']
        if 'peerId' in outs:
            self.peer_id = outs['peerId']
        if 'psk' in outs:
            self.psk = outs['psk']
        if 'region' in outs:
            self.region = outs['region']
        if 'tenantId' in outs:
            self.tenant_id = outs['tenantId']
        if 'valueSpecs' in outs:
            self.value_specs = outs['valueSpecs']
        if 'vpnserviceId' in outs:
            self.vpnservice_id = outs['vpnserviceId']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Image(pulumi.CustomResource):
    """
    Manages a V2 Image resource within OpenStack Glance.
    """
    def __init__(__self__, __name__, __opts__=None, container_format=None, disk_format=None, image_cache_path=None, image_source_url=None, local_file_path=None, min_disk_gb=None, min_ram_mb=None, name=None, properties=None, protected=None, region=None, tags=None, verify_checksum=None, visibility=None):
        """Create a Image resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if not container_format:
            raise TypeError('Missing required property container_format')
        elif not isinstance(container_format, basestring):
            raise TypeError('Expected property container_format to be a basestring')
        __self__.container_format = container_format
        """
        The container format. Must be one of
        "ami", "ari", "aki", "bare", "ovf".
        """
        __props__['containerFormat'] = container_format

        if not disk_format:
            raise TypeError('Missing required property disk_format')
        elif not isinstance(disk_format, basestring):
            raise TypeError('Expected property disk_format to be a basestring')
        __self__.disk_format = disk_format
        """
        The disk format. Must be one of
        "ami", "ari", "aki", "vhd", "vmdk", "raw", "qcow2", "vdi", "iso".
        """
        __props__['diskFormat'] = disk_format

        if image_cache_path and not isinstance(image_cache_path, basestring):
            raise TypeError('Expected property image_cache_path to be a basestring')
        __self__.image_cache_path = image_cache_path
        """
        This is the directory where the images will
        be downloaded. Images will be stored with a filename corresponding to
        the url's md5 hash. Defaults to "$HOME/.terraform/image_cache"
        """
        __props__['imageCachePath'] = image_cache_path

        if image_source_url and not isinstance(image_source_url, basestring):
            raise TypeError('Expected property image_source_url to be a basestring')
        __self__.image_source_url = image_source_url
        """
        This is the url of the raw image that will
        be downloaded in the `image_cache_path` before being uploaded to Glance.
        Glance is able to download image from internet but the `gophercloud` library
        does not yet provide a way to do so.
        Conflicts with `local_file_path`.
        """
        __props__['imageSourceUrl'] = image_source_url

        if local_file_path and not isinstance(local_file_path, basestring):
            raise TypeError('Expected property local_file_path to be a basestring')
        __self__.local_file_path = local_file_path
        """
        This is the filepath of the raw image file
        that will be uploaded to Glance. Conflicts with `image_source_url`.
        """
        __props__['localFilePath'] = local_file_path

        if min_disk_gb and not isinstance(min_disk_gb, int):
            raise TypeError('Expected property min_disk_gb to be a int')
        __self__.min_disk_gb = min_disk_gb
        """
        Amount of disk space (in GB) required to boot image.
        Defaults to 0.
        """
        __props__['minDiskGb'] = min_disk_gb

        if min_ram_mb and not isinstance(min_ram_mb, int):
            raise TypeError('Expected property min_ram_mb to be a int')
        __self__.min_ram_mb = min_ram_mb
        """
        Amount of ram (in MB) required to boot image.
        Defauts to 0.
        """
        __props__['minRamMb'] = min_ram_mb

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        The name of the image.
        """
        __props__['name'] = name

        if properties and not isinstance(properties, dict):
            raise TypeError('Expected property properties to be a dict')
        __self__.properties = properties
        """
        A map of key/value pairs to set freeform
        information about an image.
        """
        __props__['properties'] = properties

        if protected and not isinstance(protected, bool):
            raise TypeError('Expected property protected to be a bool')
        __self__.protected = protected
        """
        If true, image will not be deletable.
        Defaults to false.
        """
        __props__['protected'] = protected

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Glance client.
        A Glance client is needed to create an Image that can be used with
        a compute instance. If omitted, the `region` argument of the provider
        is used. Changing this creates a new Image.
        """
        __props__['region'] = region

        if tags and not isinstance(tags, list):
            raise TypeError('Expected property tags to be a list')
        __self__.tags = tags
        """
        The tags of the image. It must be a list of strings.
        At this time, it is not possible to delete all tags of an image.
        """
        __props__['tags'] = tags

        if verify_checksum and not isinstance(verify_checksum, bool):
            raise TypeError('Expected property verify_checksum to be a bool')
        __self__.verify_checksum = verify_checksum
        """
        If false, the checksum will not be verified
        once the image is finished uploading. Defaults to true.
        """
        __props__['verifyChecksum'] = verify_checksum

        if visibility and not isinstance(visibility, basestring):
            raise TypeError('Expected property visibility to be a basestring')
        __self__.visibility = visibility
        """
        The visibility of the image. Must be one of
        "public", "private", "community", or "shared". The ability to set the
        visibility depends upon the configuration of the OpenStack cloud.
        """
        __props__['visibility'] = visibility

        __self__.checksum = pulumi.runtime.UNKNOWN
        """
        The checksum of the data associated with the image.
        """
        __self__.created_at = pulumi.runtime.UNKNOWN
        """
        The date the image was created.
        """
        __self__.file = pulumi.runtime.UNKNOWN
        """
        the trailing path after the glance
        endpoint that represent the location of the image
        or the path to retrieve it.
        """
        __self__.metadata = pulumi.runtime.UNKNOWN
        """
        The metadata associated with the image.
        Image metadata allow for meaningfully define the image properties
        and tags. See http://docs.openstack.org/developer/glance/metadefs-concepts.html.
        """
        __self__.owner = pulumi.runtime.UNKNOWN
        """
        The id of the openstack user who owns the image.
        """
        __self__.schema = pulumi.runtime.UNKNOWN
        """
        The path to the JSON-schema that represent
        the image or image
        """
        __self__.size_bytes = pulumi.runtime.UNKNOWN
        """
        The size in bytes of the data associated with the image.
        """
        __self__.status = pulumi.runtime.UNKNOWN
        """
        The status of the image. It can be "queued", "active"
        or "saving".
        """
        __self__.update_at = pulumi.runtime.UNKNOWN
        """
        The date the image was last updated.
        """

        super(Image, __self__).__init__(
            'openstack:images/image:Image',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'checksum' in outs:
            self.checksum = outs['checksum']
        if 'containerFormat' in outs:
            self.container_format = outs['containerFormat']
        if 'createdAt' in outs:
            self.created_at = outs['createdAt']
        if 'diskFormat' in outs:
            self.disk_format = outs['diskFormat']
        if 'file' in outs:
            self.file = outs['file']
        if 'imageCachePath' in outs:
            self.image_cache_path = outs['imageCachePath']
        if 'imageSourceUrl' in outs:
            self.image_source_url = outs['imageSourceUrl']
        if 'localFilePath' in outs:
            self.local_file_path = outs['localFilePath']
        if 'metadata' in outs:
            self.metadata = outs['metadata']
        if 'minDiskGb' in outs:
            self.min_disk_gb = outs['minDiskGb']
        if 'minRamMb' in outs:
            self.min_ram_mb = outs['minRamMb']
        if 'name' in outs:
            self.name = outs['name']
        if 'owner' in outs:
            self.owner = outs['owner']
        if 'properties' in outs:
            self.properties = outs['properties']
        if 'protected' in outs:
            self.protected = outs['protected']
        if 'region' in outs:
            self.region = outs['region']
        if 'schema' in outs:
            self.schema = outs['schema']
        if 'sizeBytes' in outs:
            self.size_bytes = outs['sizeBytes']
        if 'status' in outs:
            self.status = outs['status']
        if 'tags' in outs:
            self.tags = outs['tags']
        if 'updateAt' in outs:
            self.update_at = outs['updateAt']
        if 'verifyChecksum' in outs:
            self.verify_checksum = outs['verifyChecksum']
        if 'visibility' in outs:
            self.visibility = outs['visibility']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class VolumeV1(pulumi.CustomResource):
    """
    Manages a V1 volume resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, availability_zone=None, description=None, image_id=None, metadata=None, name=None, region=None, size=None, snapshot_id=None, source_vol_id=None, volume_type=None):
        """Create a VolumeV1 resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if availability_zone and not isinstance(availability_zone, basestring):
            raise TypeError('Expected property availability_zone to be a basestring')
        __self__.availability_zone = availability_zone
        """
        The availability zone for the volume.
        Changing this creates a new volume.
        """
        __props__['availabilityZone'] = availability_zone

        if description and not isinstance(description, basestring):
            raise TypeError('Expected property description to be a basestring')
        __self__.description = description
        """
        A description of the volume. Changing this updates
        the volume's description.
        """
        __props__['description'] = description

        if image_id and not isinstance(image_id, basestring):
            raise TypeError('Expected property image_id to be a basestring')
        __self__.image_id = image_id
        """
        The image ID from which to create the volume.
        Changing this creates a new volume.
        """
        __props__['imageId'] = image_id

        if metadata and not isinstance(metadata, dict):
            raise TypeError('Expected property metadata to be a dict')
        __self__.metadata = metadata
        """
        Metadata key/value pairs to associate with the volume.
        Changing this updates the existing volume metadata.
        """
        __props__['metadata'] = metadata

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        A unique name for the volume. Changing this updates the
        volume's name.
        """
        __props__['name'] = name

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to create the volume. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new volume.
        """
        __props__['region'] = region

        if not size:
            raise TypeError('Missing required property size')
        elif not isinstance(size, int):
            raise TypeError('Expected property size to be a int')
        __self__.size = size
        """
        The size of the volume to create (in gigabytes). Changing
        this creates a new volume.
        """
        __props__['size'] = size

        if snapshot_id and not isinstance(snapshot_id, basestring):
            raise TypeError('Expected property snapshot_id to be a basestring')
        __self__.snapshot_id = snapshot_id
        """
        The snapshot ID from which to create the volume.
        Changing this creates a new volume.
        """
        __props__['snapshotId'] = snapshot_id

        if source_vol_id and not isinstance(source_vol_id, basestring):
            raise TypeError('Expected property source_vol_id to be a basestring')
        __self__.source_vol_id = source_vol_id
        """
        The volume ID from which to create the volume.
        Changing this creates a new volume.
        """
        __props__['sourceVolId'] = source_vol_id

        if volume_type and not isinstance(volume_type, basestring):
            raise TypeError('Expected property volume_type to be a basestring')
        __self__.volume_type = volume_type
        """
        The type of volume to create.
        Changing this creates a new volume.
        """
        __props__['volumeType'] = volume_type

        __self__.attachments = pulumi.runtime.UNKNOWN
        """
        If a volume is attached to an instance, this attribute will
        display the Attachment ID, Instance ID, and the Device as the Instance
        sees it.
        """

        super(VolumeV1, __self__).__init__(
            'openstack:blockstorage/volumeV1:VolumeV1',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'attachments' in outs:
            self.attachments = outs['attachments']
        if 'availabilityZone' in outs:
            self.availability_zone = outs['availabilityZone']
        if 'description' in outs:
            self.description = outs['description']
        if 'imageId' in outs:
            self.image_id = outs['imageId']
        if 'metadata' in outs:
            self.metadata = outs['metadata']
        if 'name' in outs:
            self.name = outs['name']
        if 'region' in outs:
            self.region = outs['region']
        if 'size' in outs:
            self.size = outs['size']
        if 'snapshotId' in outs:
            self.snapshot_id = outs['snapshotId']
        if 'sourceVolId' in outs:
            self.source_vol_id = outs['sourceVolId']
        if 'volumeType' in outs:
            self.volume_type = outs['volumeType']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class User(pulumi.CustomResource):
    """
    Manages a V3 User resource within OpenStack Keystone.
    
    Note: You _must_ have admin privileges in your OpenStack cloud to use
    this resource.
    """
    def __init__(__self__, __name__, __opts__=None, default_project_id=None, description=None, domain_id=None, enabled=None, extra=None, ignore_change_password_upon_first_use=None, ignore_lockout_failure_attempts=None, ignore_password_expiry=None, multi_factor_auth_enabled=None, multi_factor_auth_rules=None, name=None, password=None, region=None):
        """Create a User resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if default_project_id and not isinstance(default_project_id, basestring):
            raise TypeError('Expected property default_project_id to be a basestring')
        __self__.default_project_id = default_project_id
        """
        The default project this user belongs to.
        """
        __props__['defaultProjectId'] = default_project_id

        if description and not isinstance(description, basestring):
            raise TypeError('Expected property description to be a basestring')
        __self__.description = description
        """
        A description of the user.
        """
        __props__['description'] = description

        if domain_id and not isinstance(domain_id, basestring):
            raise TypeError('Expected property domain_id to be a basestring')
        __self__.domain_id = domain_id
        """
        The domain this user belongs to.
        """
        __props__['domainId'] = domain_id

        if enabled and not isinstance(enabled, bool):
            raise TypeError('Expected property enabled to be a bool')
        __self__.enabled = enabled
        """
        Whether the user is enabled or disabled. Valid
        values are `true` and `false`.
        """
        __props__['enabled'] = enabled

        if extra and not isinstance(extra, dict):
            raise TypeError('Expected property extra to be a dict')
        __self__.extra = extra
        """
        Free-form key/value pairs of extra information.
        """
        __props__['extra'] = extra

        if ignore_change_password_upon_first_use and not isinstance(ignore_change_password_upon_first_use, bool):
            raise TypeError('Expected property ignore_change_password_upon_first_use to be a bool')
        __self__.ignore_change_password_upon_first_use = ignore_change_password_upon_first_use
        """
        User will not have to
        change their password upon first use. Valid values are `true` and `false`.
        """
        __props__['ignoreChangePasswordUponFirstUse'] = ignore_change_password_upon_first_use

        if ignore_lockout_failure_attempts and not isinstance(ignore_lockout_failure_attempts, bool):
            raise TypeError('Expected property ignore_lockout_failure_attempts to be a bool')
        __self__.ignore_lockout_failure_attempts = ignore_lockout_failure_attempts
        """
        User will not have a failure
        lockout placed on their account. Valid values are `true` and `false`.
        """
        __props__['ignoreLockoutFailureAttempts'] = ignore_lockout_failure_attempts

        if ignore_password_expiry and not isinstance(ignore_password_expiry, bool):
            raise TypeError('Expected property ignore_password_expiry to be a bool')
        __self__.ignore_password_expiry = ignore_password_expiry
        """
        User's password will not expire.
        Valid values are `true` and `false`.
        """
        __props__['ignorePasswordExpiry'] = ignore_password_expiry

        if multi_factor_auth_enabled and not isinstance(multi_factor_auth_enabled, bool):
            raise TypeError('Expected property multi_factor_auth_enabled to be a bool')
        __self__.multi_factor_auth_enabled = multi_factor_auth_enabled
        """
        Whether to enable multi-factor
        authentication. Valid values are `true` and `false`.
        """
        __props__['multiFactorAuthEnabled'] = multi_factor_auth_enabled

        if multi_factor_auth_rules and not isinstance(multi_factor_auth_rules, list):
            raise TypeError('Expected property multi_factor_auth_rules to be a list')
        __self__.multi_factor_auth_rules = multi_factor_auth_rules
        """
        A multi-factor authentication rule.
        The structure is documented below. Please see the
        [Ocata release notes](https://docs.openstack.org/releasenotes/keystone/ocata.html)
        for more information on how to use mulit-factor rules.
        """
        __props__['multiFactorAuthRules'] = multi_factor_auth_rules

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        The name of the user.
        """
        __props__['name'] = name

        if password and not isinstance(password, basestring):
            raise TypeError('Expected property password to be a basestring')
        __self__.password = password
        """
        The password for the user.
        """
        __props__['password'] = password

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V3 Keystone client.
        If omitted, the `region` argument of the provider is used. Changing this
        creates a new User.
        """
        __props__['region'] = region

        super(User, __self__).__init__(
            'openstack:identity/user:User',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'defaultProjectId' in outs:
            self.default_project_id = outs['defaultProjectId']
        if 'description' in outs:
            self.description = outs['description']
        if 'domainId' in outs:
            self.domain_id = outs['domainId']
        if 'enabled' in outs:
            self.enabled = outs['enabled']
        if 'extra' in outs:
            self.extra = outs['extra']
        if 'ignoreChangePasswordUponFirstUse' in outs:
            self.ignore_change_password_upon_first_use = outs['ignoreChangePasswordUponFirstUse']
        if 'ignoreLockoutFailureAttempts' in outs:
            self.ignore_lockout_failure_attempts = outs['ignoreLockoutFailureAttempts']
        if 'ignorePasswordExpiry' in outs:
            self.ignore_password_expiry = outs['ignorePasswordExpiry']
        if 'multiFactorAuthEnabled' in outs:
            self.multi_factor_auth_enabled = outs['multiFactorAuthEnabled']
        if 'multiFactorAuthRules' in outs:
            self.multi_factor_auth_rules = outs['multiFactorAuthRules']
        if 'name' in outs:
            self.name = outs['name']
        if 'password' in outs:
            self.password = outs['password']
        if 'region' in outs:
            self.region = outs['region']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Zone(pulumi.CustomResource):
    """
    Manages a DNS zone in the OpenStack DNS Service.
    """
    def __init__(__self__, __name__, __opts__=None, attributes=None, description=None, email=None, masters=None, name=None, region=None, ttl=None, type=None, value_specs=None):
        """Create a Zone resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if attributes and not isinstance(attributes, dict):
            raise TypeError('Expected property attributes to be a dict')
        __self__.attributes = attributes
        """
        Attributes for the DNS Service scheduler.
        Changing this creates a new zone.
        """
        __props__['attributes'] = attributes

        if description and not isinstance(description, basestring):
            raise TypeError('Expected property description to be a basestring')
        __self__.description = description
        """
        A description of the zone.
        """
        __props__['description'] = description

        if email and not isinstance(email, basestring):
            raise TypeError('Expected property email to be a basestring')
        __self__.email = email
        """
        The email contact for the zone record.
        """
        __props__['email'] = email

        if masters and not isinstance(masters, list):
            raise TypeError('Expected property masters to be a list')
        __self__.masters = masters
        """
        An array of master DNS servers. For when `type` is
        `SECONDARY`.
        """
        __props__['masters'] = masters

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        The name of the zone. Note the `.` at the end of the name.
        Changing this creates a new DNS zone.
        """
        __props__['name'] = name

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Compute client.
        Keypairs are associated with accounts, but a Compute client is needed to
        create one. If omitted, the `region` argument of the provider is used.
        Changing this creates a new DNS zone.
        """
        __props__['region'] = region

        if ttl and not isinstance(ttl, int):
            raise TypeError('Expected property ttl to be a int')
        __self__.ttl = ttl
        """
        The time to live (TTL) of the zone.
        """
        __props__['ttl'] = ttl

        if type and not isinstance(type, basestring):
            raise TypeError('Expected property type to be a basestring')
        __self__.type = type
        """
        The type of zone. Can either be `PRIMARY` or `SECONDARY`.
        Changing this creates a new zone.
        """
        __props__['type'] = type

        if value_specs and not isinstance(value_specs, dict):
            raise TypeError('Expected property value_specs to be a dict')
        __self__.value_specs = value_specs
        """
        Map of additional options. Changing this creates a
        new zone.
        """
        __props__['valueSpecs'] = value_specs

        super(Zone, __self__).__init__(
            'openstack:dns/zone:Zone',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'attributes' in outs:
            self.attributes = outs['attributes']
        if 'description' in outs:
            self.description = outs['description']
        if 'email' in outs:
            self.email = outs['email']
        if 'masters' in outs:
            self.masters = outs['masters']
        if 'name' in outs:
            self.name = outs['name']
        if 'region' in outs:
            self.region = outs['region']
        if 'ttl' in outs:
            self.ttl = outs['ttl']
        if 'type' in outs:
            self.type = outs['type']
        if 'valueSpecs' in outs:
            self.value_specs = outs['valueSpecs']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class GetSubnetPoolResult(object):
    """
    A collection of values returned by getSubnetPool.
    """
    def __init__(__self__, address_scope_id=None, created_at=None, default_prefixlen=None, default_quota=None, description=None, ip_version=None, is_default=None, max_prefixlen=None, min_prefixlen=None, name=None, prefixes=None, project_id=None, region=None, revision_number=None, shared=None, updated_at=None):
        if address_scope_id and not isinstance(address_scope_id, basestring):
            raise TypeError('Expected argument address_scope_id to be a basestring')
        __self__.address_scope_id = address_scope_id
        """
        See Argument Reference above.
        * `ip_version` -The IP protocol version.
        """
        if created_at and not isinstance(created_at, basestring):
            raise TypeError('Expected argument created_at to be a basestring')
        __self__.created_at = created_at
        """
        The time at which subnetpool was created.
        """
        if default_prefixlen and not isinstance(default_prefixlen, int):
            raise TypeError('Expected argument default_prefixlen to be a int')
        __self__.default_prefixlen = default_prefixlen
        """
        See Argument Reference above.
        """
        if default_quota and not isinstance(default_quota, int):
            raise TypeError('Expected argument default_quota to be a int')
        __self__.default_quota = default_quota
        """
        See Argument Reference above.
        """
        if description and not isinstance(description, basestring):
            raise TypeError('Expected argument description to be a basestring')
        __self__.description = description
        """
        See Argument Reference above.
        """
        if ip_version and not isinstance(ip_version, int):
            raise TypeError('Expected argument ip_version to be a int')
        __self__.ip_version = ip_version
        if is_default and not isinstance(is_default, bool):
            raise TypeError('Expected argument is_default to be a bool')
        __self__.is_default = is_default
        """
        See Argument Reference above.
        """
        if max_prefixlen and not isinstance(max_prefixlen, int):
            raise TypeError('Expected argument max_prefixlen to be a int')
        __self__.max_prefixlen = max_prefixlen
        """
        See Argument Reference above.
        """
        if min_prefixlen and not isinstance(min_prefixlen, int):
            raise TypeError('Expected argument min_prefixlen to be a int')
        __self__.min_prefixlen = min_prefixlen
        """
        See Argument Reference above.
        """
        if name and not isinstance(name, basestring):
            raise TypeError('Expected argument name to be a basestring')
        __self__.name = name
        """
        See Argument Reference above.
        """
        if prefixes and not isinstance(prefixes, list):
            raise TypeError('Expected argument prefixes to be a list')
        __self__.prefixes = prefixes
        """
        See Argument Reference above.
        """
        if project_id and not isinstance(project_id, basestring):
            raise TypeError('Expected argument project_id to be a basestring')
        __self__.project_id = project_id
        """
        See Argument Reference above.
        """
        if region and not isinstance(region, basestring):
            raise TypeError('Expected argument region to be a basestring')
        __self__.region = region
        """
        See Argument Reference above.
        """
        if revision_number and not isinstance(revision_number, int):
            raise TypeError('Expected argument revision_number to be a int')
        __self__.revision_number = revision_number
        """
        The revision number of the subnetpool.
        """
        if shared and not isinstance(shared, bool):
            raise TypeError('Expected argument shared to be a bool')
        __self__.shared = shared
        """
        See Argument Reference above.
        """
        if updated_at and not isinstance(updated_at, basestring):
            raise TypeError('Expected argument updated_at to be a basestring')
        __self__.updated_at = updated_at
        """
        The time at which subnetpool was created.
        """

def get_subnet_pool(address_scope_id=None, default_prefixlen=None, default_quota=None, description=None, ip_version=None, is_default=None, max_prefixlen=None, min_prefixlen=None, name=None, project_id=None, region=None, shared=None):
    """
    Use this data source to get the ID of an available OpenStack subnetpool.
    """
    __args__ = dict()

    __args__['addressScopeId'] = address_scope_id
    __args__['defaultPrefixlen'] = default_prefixlen
    __args__['defaultQuota'] = default_quota
    __args__['description'] = description
    __args__['ipVersion'] = ip_version
    __args__['isDefault'] = is_default
    __args__['maxPrefixlen'] = max_prefixlen
    __args__['minPrefixlen'] = min_prefixlen
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['shared'] = shared
    __ret__ = pulumi.runtime.invoke('openstack:networking/getSubnetPool:getSubnetPool', __args__)

    return GetSubnetPoolResult(
        address_scope_id=__ret__.get('addressScopeId'),
        created_at=__ret__.get('createdAt'),
        default_prefixlen=__ret__.get('defaultPrefixlen'),
        default_quota=__ret__.get('defaultQuota'),
        description=__ret__.get('description'),
        ip_version=__ret__.get('ipVersion'),
        is_default=__ret__.get('isDefault'),
        max_prefixlen=__ret__.get('maxPrefixlen'),
        min_prefixlen=__ret__.get('minPrefixlen'),
        name=__ret__.get('name'),
        prefixes=__ret__.get('prefixes'),
        project_id=__ret__.get('projectId'),
        region=__ret__.get('region'),
        revision_number=__ret__.get('revisionNumber'),
        shared=__ret__.get('shared'),
        updated_at=__ret__.get('updatedAt'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Container(pulumi.CustomResource):
    """
    Manages a V1 container resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, container_read=None, container_sync_key=None, container_sync_to=None, container_write=None, content_type=None, force_destroy=None, metadata=None, name=None, region=None):
        """Create a Container resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if container_read and not isinstance(container_read, basestring):
            raise TypeError('Expected property container_read to be a basestring')
        __self__.container_read = container_read
        """
        Sets an access control list (ACL) that grants
        read access. This header can contain a comma-delimited list of users that
        can read the container (allows the GET method for all objects in the
        container). Changing this updates the access control list read access.
        """
        __props__['containerRead'] = container_read

        if container_sync_key and not isinstance(container_sync_key, basestring):
            raise TypeError('Expected property container_sync_key to be a basestring')
        __self__.container_sync_key = container_sync_key
        """
        The secret key for container synchronization.
        Changing this updates container synchronization.
        """
        __props__['containerSyncKey'] = container_sync_key

        if container_sync_to and not isinstance(container_sync_to, basestring):
            raise TypeError('Expected property container_sync_to to be a basestring')
        __self__.container_sync_to = container_sync_to
        """
        The destination for container synchronization.
        Changing this updates container synchronization.
        """
        __props__['containerSyncTo'] = container_sync_to

        if container_write and not isinstance(container_write, basestring):
            raise TypeError('Expected property container_write to be a basestring')
        __self__.container_write = container_write
        """
        Sets an ACL that grants write access.
        Changing this updates the access control list write access.
        """
        __props__['containerWrite'] = container_write

        if content_type and not isinstance(content_type, basestring):
            raise TypeError('Expected property content_type to be a basestring')
        __self__.content_type = content_type
        """
        The MIME type for the container. Changing this
        updates the MIME type.
        """
        __props__['contentType'] = content_type

        if force_destroy and not isinstance(force_destroy, bool):
            raise TypeError('Expected property force_destroy to be a bool')
        __self__.force_destroy = force_destroy
        """
        A boolean that indicates all objects should be deleted from the container so that the container can be destroyed without error. These objects are not recoverable.
        """
        __props__['forceDestroy'] = force_destroy

        if metadata and not isinstance(metadata, dict):
            raise TypeError('Expected property metadata to be a dict')
        __self__.metadata = metadata
        """
        Custom key/value pairs to associate with the container.
        Changing this updates the existing container metadata.
        """
        __props__['metadata'] = metadata

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        A unique name for the container. Changing this creates a
        new container.
        """
        __props__['name'] = name

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to create the container. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new container.
        """
        __props__['region'] = region

        super(Container, __self__).__init__(
            'openstack:objectstorage/container:Container',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'containerRead' in outs:
            self.container_read = outs['containerRead']
        if 'containerSyncKey' in outs:
            self.container_sync_key = outs['containerSyncKey']
        if 'containerSyncTo' in outs:
            self.container_sync_to = outs['containerSyncTo']
        if 'containerWrite' in outs:
            self.container_write = outs['containerWrite']
        if 'contentType' in outs:
            self.content_type = outs['contentType']
        if 'forceDestroy' in outs:
            self.force_destroy = outs['forceDestroy']
        if 'metadata' in outs:
            self.metadata = outs['metadata']
        if 'name' in outs:
            self.name = outs['name']
        if 'region' in outs:
            self.region = outs['region']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Flavor(pulumi.CustomResource):
    """
    Manages a V2 flavor resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, disk=None, ephemeral=None, extra_specs=None, is_public=None, name=None, ram=None, region=None, rx_tx_factor=None, swap=None, vcpus=None):
        """Create a Flavor resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if not disk:
            raise TypeError('Missing required property disk')
        elif not isinstance(disk, int):
            raise TypeError('Expected property disk to be a int')
        __self__.disk = disk
        """
        The amount of disk space in gigabytes to use for the root
        (/) partition. Changing this creates a new flavor.
        """
        __props__['disk'] = disk

        if ephemeral and not isinstance(ephemeral, int):
            raise TypeError('Expected property ephemeral to be a int')
        __self__.ephemeral = ephemeral
        __props__['ephemeral'] = ephemeral

        if extra_specs and not isinstance(extra_specs, dict):
            raise TypeError('Expected property extra_specs to be a dict')
        __self__.extra_specs = extra_specs
        """
        Key/Value pairs of metadata for the flavor.
        """
        __props__['extraSpecs'] = extra_specs

        if is_public and not isinstance(is_public, bool):
            raise TypeError('Expected property is_public to be a bool')
        __self__.is_public = is_public
        """
        Whether the flavor is public. Changing this creates
        a new flavor.
        """
        __props__['isPublic'] = is_public

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        A unique name for the flavor. Changing this creates a new
        flavor.
        """
        __props__['name'] = name

        if not ram:
            raise TypeError('Missing required property ram')
        elif not isinstance(ram, int):
            raise TypeError('Expected property ram to be a int')
        __self__.ram = ram
        """
        The amount of RAM to use, in megabytes. Changing this
        creates a new flavor.
        """
        __props__['ram'] = ram

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Compute client.
        Flavors are associated with accounts, but a Compute client is needed to
        create one. If omitted, the `region` argument of the provider is used.
        Changing this creates a new flavor.
        """
        __props__['region'] = region

        if rx_tx_factor and not isinstance(rx_tx_factor, float):
            raise TypeError('Expected property rx_tx_factor to be a float')
        __self__.rx_tx_factor = rx_tx_factor
        """
        RX/TX bandwith factor. The default is 1. Changing
        this creates a new flavor.
        """
        __props__['rxTxFactor'] = rx_tx_factor

        if swap and not isinstance(swap, int):
            raise TypeError('Expected property swap to be a int')
        __self__.swap = swap
        """
        The amount of disk space in megabytes to use. If
        unspecified, the default is 0. Changing this creates a new flavor.
        """
        __props__['swap'] = swap

        if not vcpus:
            raise TypeError('Missing required property vcpus')
        elif not isinstance(vcpus, int):
            raise TypeError('Expected property vcpus to be a int')
        __self__.vcpus = vcpus
        """
        The number of virtual CPUs to use. Changing this creates
        a new flavor.
        """
        __props__['vcpus'] = vcpus

        super(Flavor, __self__).__init__(
            'openstack:compute/flavor:Flavor',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'disk' in outs:
            self.disk = outs['disk']
        if 'ephemeral' in outs:
            self.ephemeral = outs['ephemeral']
        if 'extraSpecs' in outs:
            self.extra_specs = outs['extraSpecs']
        if 'isPublic' in outs:
            self.is_public = outs['isPublic']
        if 'name' in outs:
            self.name = outs['name']
        if 'ram' in outs:
            self.ram = outs['ram']
        if 'region' in outs:
            self.region = outs['region']
        if 'rxTxFactor' in outs:
            self.rx_tx_factor = outs['rxTxFactor']
        if 'swap' in outs:
            self.swap = outs['swap']
        if 'vcpus' in outs:
            self.vcpus = outs['vcpus']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

__config__ = pulumi.Config('openstack')

auth_url = __config__.get('authUrl')
"""
The Identity authentication URL.
"""

cacert_file = __config__.get('cacertFile')
"""
A Custom CA certificate.
"""

cert = __config__.get('cert')
"""
A client certificate to authenticate with.
"""

cloud = __config__.get('cloud')
"""
An entry in a `clouds.yaml` file to use.
"""

domain_id = __config__.get('domainId')
"""
The ID of the Domain to scope to (Identity v3).
"""

domain_name = __config__.get('domainName')
"""
The name of the Domain to scope to (Identity v3).
"""

endpoint_type = __config__.get('endpointType')

insecure = __config__.get('insecure')
"""
Trust self-signed certificates.
"""

key = __config__.get('key')
"""
A client private key to authenticate with.
"""

password = __config__.get('password')
"""
Password to login with.
"""

project_domain_id = __config__.get('projectDomainId')
"""
The ID of the domain where the proejct resides (Identity v3).
"""

project_domain_name = __config__.get('projectDomainName')
"""
The name of the domain where the project resides (Identity v3).
"""

region = __config__.get('region')
"""
The OpenStack region to connect to.
"""

swauth = __config__.get('swauth')
"""
Use Swift's authentication system instead of Keystone. Only used for interaction with Swift.
"""

tenant_id = __config__.get('tenantId')
"""
The ID of the Tenant (Identity v2) or Project (Identity v3) to login with.
"""

tenant_name = __config__.get('tenantName')
"""
The name of the Tenant (Identity v2) or Project (Identity v3) to login with.
"""

token = __config__.get('token')
"""
Authentication token to use as an alternative to username/password.
"""

use_octavia = __config__.get('useOctavia')
"""
If set to `true`, API requests will go the Load Balancer service (Octavia) instead of the Networking service (Neutron).
"""

user_domain_id = __config__.get('userDomainId')
"""
The ID of the domain where the user resides (Identity v3).
"""

user_domain_name = __config__.get('userDomainName')
"""
The name of the domain where the user resides (Identity v3).
"""

user_id = __config__.get('userId')
"""
Username to login with.
"""

user_name = __config__.get('userName')
"""
Username to login with.
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from floating_ip_associate import *
from floating_ip import *
from network import *
from port import *
from router_interface import *
from router_route import *
from router import *
from sec_group_rule import *
from sec_group import *
from subnet_route import *
from subnet import *
from subnet_pool import *
from get_network import *
from get_sec_group import *
from get_subnet import *
from get_subnet_pool import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from flavor import *
from floating_ip_associate import *
from floating_i_p import *
from instance import *
from keypair import *
from sec_group import *
from server_group import *
from volume_attach import *
from get_flavor import *
from get_keypair import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class FloatingIpAssociate(pulumi.CustomResource):
    """
    Associates a floating IP to a port. This is useful for situations
    where you have a pre-allocated floating IP or are unable to use the
    `openstack_networking_floatingip_v2` resource to create a floating IP.
    """
    def __init__(__self__, __name__, __opts__=None, floating_ip=None, port_id=None, region=None):
        """Create a FloatingIpAssociate resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if not floating_ip:
            raise TypeError('Missing required property floating_ip')
        elif not isinstance(floating_ip, basestring):
            raise TypeError('Expected property floating_ip to be a basestring')
        __self__.floating_ip = floating_ip
        """
        IP Address of an existing floating IP.
        """
        __props__['floatingIp'] = floating_ip

        if not port_id:
            raise TypeError('Missing required property port_id')
        elif not isinstance(port_id, basestring):
            raise TypeError('Expected property port_id to be a basestring')
        __self__.port_id = port_id
        """
        ID of an existing port with at least one IP address to
        associate with this floating IP.
        """
        __props__['portId'] = port_id

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a floating IP that can be used with
        another networking resource, such as a load balancer. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        floating IP (which may or may not have a different address).
        """
        __props__['region'] = region

        super(FloatingIpAssociate, __self__).__init__(
            'openstack:networking/floatingIpAssociate:FloatingIpAssociate',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'floatingIp' in outs:
            self.floating_ip = outs['floatingIp']
        if 'portId' in outs:
            self.port_id = outs['portId']
        if 'region' in outs:
            self.region = outs['region']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Rule(pulumi.CustomResource):
    """
    Manages a v1 firewall rule resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, action=None, description=None, destination_ip_address=None, destination_port=None, enabled=None, ip_version=None, name=None, protocol=None, region=None, source_ip_address=None, source_port=None, tenant_id=None, value_specs=None):
        """Create a Rule resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if not action:
            raise TypeError('Missing required property action')
        elif not isinstance(action, basestring):
            raise TypeError('Expected property action to be a basestring')
        __self__.action = action
        """
        Action to be taken ( must be "allow" or "deny") when the
        firewall rule matches. Changing this updates the `action` of an existing
        firewall rule.
        """
        __props__['action'] = action

        if description and not isinstance(description, basestring):
            raise TypeError('Expected property description to be a basestring')
        __self__.description = description
        """
        A description for the firewall rule. Changing this
        updates the `description` of an existing firewall rule.
        """
        __props__['description'] = description

        if destination_ip_address and not isinstance(destination_ip_address, basestring):
            raise TypeError('Expected property destination_ip_address to be a basestring')
        __self__.destination_ip_address = destination_ip_address
        """
        The destination IP address on which the
        firewall rule operates. Changing this updates the `destination_ip_address`
        of an existing firewall rule.
        """
        __props__['destinationIpAddress'] = destination_ip_address

        if destination_port and not isinstance(destination_port, basestring):
            raise TypeError('Expected property destination_port to be a basestring')
        __self__.destination_port = destination_port
        """
        The destination port on which the firewall
        rule operates. Changing this updates the `destination_port` of an existing
        firewall rule.
        """
        __props__['destinationPort'] = destination_port

        if enabled and not isinstance(enabled, bool):
            raise TypeError('Expected property enabled to be a bool')
        __self__.enabled = enabled
        """
        Enabled status for the firewall rule (must be "true"
        or "false" if provided - defaults to "true"). Changing this updates the
        `enabled` status of an existing firewall rule.
        """
        __props__['enabled'] = enabled

        if ip_version and not isinstance(ip_version, int):
            raise TypeError('Expected property ip_version to be a int')
        __self__.ip_version = ip_version
        """
        IP version, either 4 (default) or 6. Changing this
        updates the `ip_version` of an existing firewall rule.
        """
        __props__['ipVersion'] = ip_version

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        A unique name for the firewall rule. Changing this
        updates the `name` of an existing firewall rule.
        """
        __props__['name'] = name

        if not protocol:
            raise TypeError('Missing required property protocol')
        elif not isinstance(protocol, basestring):
            raise TypeError('Expected property protocol to be a basestring')
        __self__.protocol = protocol
        """
        The protocol type on which the firewall rule operates.
        Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
        `protocol` of an existing firewall rule.
        """
        __props__['protocol'] = protocol

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the v1 Compute client.
        A Compute client is needed to create a firewall rule. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        firewall rule.
        """
        __props__['region'] = region

        if source_ip_address and not isinstance(source_ip_address, basestring):
            raise TypeError('Expected property source_ip_address to be a basestring')
        __self__.source_ip_address = source_ip_address
        """
        The source IP address on which the firewall
        rule operates. Changing this updates the `source_ip_address` of an existing
        firewall rule.
        """
        __props__['sourceIpAddress'] = source_ip_address

        if source_port and not isinstance(source_port, basestring):
            raise TypeError('Expected property source_port to be a basestring')
        __self__.source_port = source_port
        """
        The source port on which the firewall
        rule operates. Changing this updates the `source_port` of an existing
        firewall rule.
        """
        __props__['sourcePort'] = source_port

        if tenant_id and not isinstance(tenant_id, basestring):
            raise TypeError('Expected property tenant_id to be a basestring')
        __self__.tenant_id = tenant_id
        """
        The owner of the firewall rule. Required if admin
        wants to create a firewall rule for another tenant. Changing this creates a
        new firewall rule.
        """
        __props__['tenantId'] = tenant_id

        if value_specs and not isinstance(value_specs, dict):
            raise TypeError('Expected property value_specs to be a dict')
        __self__.value_specs = value_specs
        """
        Map of additional options.
        """
        __props__['valueSpecs'] = value_specs

        super(Rule, __self__).__init__(
            'openstack:firewall/rule:Rule',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'action' in outs:
            self.action = outs['action']
        if 'description' in outs:
            self.description = outs['description']
        if 'destinationIpAddress' in outs:
            self.destination_ip_address = outs['destinationIpAddress']
        if 'destinationPort' in outs:
            self.destination_port = outs['destinationPort']
        if 'enabled' in outs:
            self.enabled = outs['enabled']
        if 'ipVersion' in outs:
            self.ip_version = outs['ipVersion']
        if 'name' in outs:
            self.name = outs['name']
        if 'protocol' in outs:
            self.protocol = outs['protocol']
        if 'region' in outs:
            self.region = outs['region']
        if 'sourceIpAddress' in outs:
            self.source_ip_address = outs['sourceIpAddress']
        if 'sourcePort' in outs:
            self.source_port = outs['sourcePort']
        if 'tenantId' in outs:
            self.tenant_id = outs['tenantId']
        if 'valueSpecs' in outs:
            self.value_specs = outs['valueSpecs']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Monitor(pulumi.CustomResource):
    """
    Manages a V2 monitor resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, admin_state_up=None, delay=None, expected_codes=None, http_method=None, max_retries=None, name=None, pool_id=None, region=None, tenant_id=None, timeout=None, type=None, url_path=None):
        """Create a Monitor resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if admin_state_up and not isinstance(admin_state_up, bool):
            raise TypeError('Expected property admin_state_up to be a bool')
        __self__.admin_state_up = admin_state_up
        """
        The administrative state of the monitor.
        A valid value is true (UP) or false (DOWN).
        """
        __props__['adminStateUp'] = admin_state_up

        if not delay:
            raise TypeError('Missing required property delay')
        elif not isinstance(delay, int):
            raise TypeError('Expected property delay to be a int')
        __self__.delay = delay
        """
        The time, in seconds, between sending probes to members.
        """
        __props__['delay'] = delay

        if expected_codes and not isinstance(expected_codes, basestring):
            raise TypeError('Expected property expected_codes to be a basestring')
        __self__.expected_codes = expected_codes
        """
        Required for HTTP(S) types. Expected HTTP codes
        for a passing HTTP(S) monitor. You can either specify a single status like
        "200", or a range like "200-202".
        """
        __props__['expectedCodes'] = expected_codes

        if http_method and not isinstance(http_method, basestring):
            raise TypeError('Expected property http_method to be a basestring')
        __self__.http_method = http_method
        """
        Required for HTTP(S) types. The HTTP method used
        for requests by the monitor. If this attribute is not specified, it
        defaults to "GET".
        """
        __props__['httpMethod'] = http_method

        if not max_retries:
            raise TypeError('Missing required property max_retries')
        elif not isinstance(max_retries, int):
            raise TypeError('Expected property max_retries to be a int')
        __self__.max_retries = max_retries
        """
        Number of permissible ping failures before
        changing the member's status to INACTIVE. Must be a number between 1
        and 10..
        """
        __props__['maxRetries'] = max_retries

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        The Name of the Monitor.
        """
        __props__['name'] = name

        if not pool_id:
            raise TypeError('Missing required property pool_id')
        elif not isinstance(pool_id, basestring):
            raise TypeError('Expected property pool_id to be a basestring')
        __self__.pool_id = pool_id
        """
        The id of the pool that this monitor will be assigned to.
        """
        __props__['poolId'] = pool_id

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create an . If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        monitor.
        """
        __props__['region'] = region

        if tenant_id and not isinstance(tenant_id, basestring):
            raise TypeError('Expected property tenant_id to be a basestring')
        __self__.tenant_id = tenant_id
        """
        Required for admins. The UUID of the tenant who owns
        the monitor.  Only administrative users can specify a tenant UUID
        other than their own. Changing this creates a new monitor.
        """
        __props__['tenantId'] = tenant_id

        if not timeout:
            raise TypeError('Missing required property timeout')
        elif not isinstance(timeout, int):
            raise TypeError('Expected property timeout to be a int')
        __self__.timeout = timeout
        """
        Maximum number of seconds for a monitor to wait for a
        ping reply before it times out. The value must be less than the delay
        value.
        """
        __props__['timeout'] = timeout

        if not type:
            raise TypeError('Missing required property type')
        elif not isinstance(type, basestring):
            raise TypeError('Expected property type to be a basestring')
        __self__.type = type
        """
        The type of probe, which is PING, TCP, HTTP, or HTTPS,
        that is sent by the load balancer to verify the member state. Changing this
        creates a new monitor.
        """
        __props__['type'] = type

        if url_path and not isinstance(url_path, basestring):
            raise TypeError('Expected property url_path to be a basestring')
        __self__.url_path = url_path
        """
        Required for HTTP(S) types. URI path that will be
        accessed if monitor type is HTTP or HTTPS.
        """
        __props__['urlPath'] = url_path

        super(Monitor, __self__).__init__(
            'openstack:loadbalancer/monitor:Monitor',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'adminStateUp' in outs:
            self.admin_state_up = outs['adminStateUp']
        if 'delay' in outs:
            self.delay = outs['delay']
        if 'expectedCodes' in outs:
            self.expected_codes = outs['expectedCodes']
        if 'httpMethod' in outs:
            self.http_method = outs['httpMethod']
        if 'maxRetries' in outs:
            self.max_retries = outs['maxRetries']
        if 'name' in outs:
            self.name = outs['name']
        if 'poolId' in outs:
            self.pool_id = outs['poolId']
        if 'region' in outs:
            self.region = outs['region']
        if 'tenantId' in outs:
            self.tenant_id = outs['tenantId']
        if 'timeout' in outs:
            self.timeout = outs['timeout']
        if 'type' in outs:
            self.type = outs['type']
        if 'urlPath' in outs:
            self.url_path = outs['urlPath']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class GetRoleResult(object):
    """
    A collection of values returned by getRole.
    """
    def __init__(__self__, domain_id=None, region=None):
        if domain_id and not isinstance(domain_id, basestring):
            raise TypeError('Expected argument domain_id to be a basestring')
        __self__.domain_id = domain_id
        """
        See Argument Reference above.
        """
        if region and not isinstance(region, basestring):
            raise TypeError('Expected argument region to be a basestring')
        __self__.region = region
        """
        See Argument Reference above.
        """

def get_role(domain_id=None, name=None, region=None):
    """
    Use this data source to get the ID of an OpenStack role.
    """
    __args__ = dict()

    __args__['domainId'] = domain_id
    __args__['name'] = name
    __args__['region'] = region
    __ret__ = pulumi.runtime.invoke('openstack:identity/getRole:getRole', __args__)

    return GetRoleResult(
        domain_id=__ret__.get('domainId'),
        region=__ret__.get('region'))



# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from setuptools import setup, find_packages
from setuptools.command.install import install
from subprocess import check_call

class InstallPluginCommand(install):
    def run(self):
        install.run(self)
        check_call(['pulumi', 'plugin', 'install', 'resource', 'openstack', 'v0.1.0-1532186954-gd5f6dc4'])

setup(name='pulumi_openstack',
      version='0.1.0.post1532186954',
      description='A Pulumi package for creating and managing OpenStack cloud resources.',
      cmdclass={
          'install': InstallPluginCommand,
      },
      keywords='pulumi openstack',
      url='https://pulumi.io',
      project_urls={
          'Repository': 'https://github.com/pulumi/pulumi-openstack'
      },
      license='Apache 2.0',
      packages=find_packages(),
      install_requires=[
          'pulumi>=0.14.0,<0.15.0'
      ],
      zip_safe=False)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Policy(pulumi.CustomResource):
    """
    Manages a v1 firewall policy resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, audited=None, description=None, name=None, region=None, rules=None, shared=None, tenant_id=None, value_specs=None):
        """Create a Policy resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if audited and not isinstance(audited, bool):
            raise TypeError('Expected property audited to be a bool')
        __self__.audited = audited
        """
        Audit status of the firewall policy
        (must be "true" or "false" if provided - defaults to "false").
        This status is set to "false" whenever the firewall policy or any of its
        rules are changed. Changing this updates the `audited` status of an existing
        firewall policy.
        """
        __props__['audited'] = audited

        if description and not isinstance(description, basestring):
            raise TypeError('Expected property description to be a basestring')
        __self__.description = description
        """
        A description for the firewall policy. Changing
        this updates the `description` of an existing firewall policy.
        """
        __props__['description'] = description

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        A name for the firewall policy. Changing this
        updates the `name` of an existing firewall policy.
        """
        __props__['name'] = name

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the v1 networking client.
        A networking client is needed to create a firewall policy. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        firewall policy.
        """
        __props__['region'] = region

        if rules and not isinstance(rules, list):
            raise TypeError('Expected property rules to be a list')
        __self__.rules = rules
        """
        An array of one or more firewall rules that comprise
        the policy. Changing this results in adding/removing rules from the
        existing firewall policy.
        """
        __props__['rules'] = rules

        if shared and not isinstance(shared, bool):
            raise TypeError('Expected property shared to be a bool')
        __self__.shared = shared
        """
        Sharing status of the firewall policy (must be "true"
        or "false" if provided). If this is "true" the policy is visible to, and
        can be used in, firewalls in other tenants. Changing this updates the
        `shared` status of an existing firewall policy. Only administrative users
        can specify if the policy should be shared.
        """
        __props__['shared'] = shared

        if tenant_id and not isinstance(tenant_id, basestring):
            raise TypeError('Expected property tenant_id to be a basestring')
        __self__.tenant_id = tenant_id
        __props__['tenantId'] = tenant_id

        if value_specs and not isinstance(value_specs, dict):
            raise TypeError('Expected property value_specs to be a dict')
        __self__.value_specs = value_specs
        """
        Map of additional options.
        """
        __props__['valueSpecs'] = value_specs

        super(Policy, __self__).__init__(
            'openstack:firewall/policy:Policy',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'audited' in outs:
            self.audited = outs['audited']
        if 'description' in outs:
            self.description = outs['description']
        if 'name' in outs:
            self.name = outs['name']
        if 'region' in outs:
            self.region = outs['region']
        if 'rules' in outs:
            self.rules = outs['rules']
        if 'shared' in outs:
            self.shared = outs['shared']
        if 'tenantId' in outs:
            self.tenant_id = outs['tenantId']
        if 'valueSpecs' in outs:
            self.value_specs = outs['valueSpecs']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Service(pulumi.CustomResource):
    """
    Manages a V2 Neutron VPN service resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, admin_state_up=None, description=None, name=None, region=None, router_id=None, subnet_id=None, tenant_id=None, value_specs=None):
        """Create a Service resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if admin_state_up and not isinstance(admin_state_up, bool):
            raise TypeError('Expected property admin_state_up to be a bool')
        __self__.admin_state_up = admin_state_up
        """
        The administrative state of the resource. Can either be up(true) or down(false).
        Changing this updates the administrative state of the existing service.
        """
        __props__['adminStateUp'] = admin_state_up

        if description and not isinstance(description, basestring):
            raise TypeError('Expected property description to be a basestring')
        __self__.description = description
        """
        The human-readable description for the service.
        Changing this updates the description of the existing service.
        """
        __props__['description'] = description

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        The name of the service. Changing this updates the name of
        the existing service.
        """
        __props__['name'] = name

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a VPN service. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        service.
        """
        __props__['region'] = region

        if not router_id:
            raise TypeError('Missing required property router_id')
        elif not isinstance(router_id, basestring):
            raise TypeError('Expected property router_id to be a basestring')
        __self__.router_id = router_id
        """
        The ID of the router. Changing this creates a new service.
        """
        __props__['routerId'] = router_id

        if subnet_id and not isinstance(subnet_id, basestring):
            raise TypeError('Expected property subnet_id to be a basestring')
        __self__.subnet_id = subnet_id
        """
        SubnetID is the ID of the subnet. Default is null.
        """
        __props__['subnetId'] = subnet_id

        if tenant_id and not isinstance(tenant_id, basestring):
            raise TypeError('Expected property tenant_id to be a basestring')
        __self__.tenant_id = tenant_id
        """
        The owner of the service. Required if admin wants to
        create a service for another project. Changing this creates a new service.
        """
        __props__['tenantId'] = tenant_id

        if value_specs and not isinstance(value_specs, dict):
            raise TypeError('Expected property value_specs to be a dict')
        __self__.value_specs = value_specs
        """
        Map of additional options.
        """
        __props__['valueSpecs'] = value_specs

        __self__.external_v4_ip = pulumi.runtime.UNKNOWN
        """
        The read-only external (public) IPv4 address that is used for the VPN service.
        """
        __self__.external_v6_ip = pulumi.runtime.UNKNOWN
        """
        The read-only external (public) IPv6 address that is used for the VPN service.
        """
        __self__.status = pulumi.runtime.UNKNOWN
        """
        Indicates whether IPsec VPN service is currently operational. Values are ACTIVE, DOWN, BUILD, ERROR, PENDING_CREATE, PENDING_UPDATE, or PENDING_DELETE.
        """

        super(Service, __self__).__init__(
            'openstack:vpnaas/service:Service',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'adminStateUp' in outs:
            self.admin_state_up = outs['adminStateUp']
        if 'description' in outs:
            self.description = outs['description']
        if 'externalV4Ip' in outs:
            self.external_v4_ip = outs['externalV4Ip']
        if 'externalV6Ip' in outs:
            self.external_v6_ip = outs['externalV6Ip']
        if 'name' in outs:
            self.name = outs['name']
        if 'region' in outs:
            self.region = outs['region']
        if 'routerId' in outs:
            self.router_id = outs['routerId']
        if 'status' in outs:
            self.status = outs['status']
        if 'subnetId' in outs:
            self.subnet_id = outs['subnetId']
        if 'tenantId' in outs:
            self.tenant_id = outs['tenantId']
        if 'valueSpecs' in outs:
            self.value_specs = outs['valueSpecs']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class RouterInterface(pulumi.CustomResource):
    """
    Manages a V2 router interface resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, port_id=None, region=None, router_id=None, subnet_id=None):
        """Create a RouterInterface resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if port_id and not isinstance(port_id, basestring):
            raise TypeError('Expected property port_id to be a basestring')
        __self__.port_id = port_id
        """
        ID of the port this interface connects to. Changing
        this creates a new router interface.
        """
        __props__['portId'] = port_id

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 networking client.
        A networking client is needed to create a router. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        router interface.
        """
        __props__['region'] = region

        if not router_id:
            raise TypeError('Missing required property router_id')
        elif not isinstance(router_id, basestring):
            raise TypeError('Expected property router_id to be a basestring')
        __self__.router_id = router_id
        """
        ID of the router this interface belongs to. Changing
        this creates a new router interface.
        """
        __props__['routerId'] = router_id

        if subnet_id and not isinstance(subnet_id, basestring):
            raise TypeError('Expected property subnet_id to be a basestring')
        __self__.subnet_id = subnet_id
        """
        ID of the subnet this interface connects to. Changing
        this creates a new router interface.
        """
        __props__['subnetId'] = subnet_id

        super(RouterInterface, __self__).__init__(
            'openstack:networking/routerInterface:RouterInterface',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'portId' in outs:
            self.port_id = outs['portId']
        if 'region' in outs:
            self.region = outs['region']
        if 'routerId' in outs:
            self.router_id = outs['routerId']
        if 'subnetId' in outs:
            self.subnet_id = outs['subnetId']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class FloatingIP(pulumi.CustomResource):
    """
    Manages a V2 floating IP resource within OpenStack Nova (compute)
    that can be used for compute instances.
    
    Please note that managing floating IPs through the OpenStack Compute API has
    been deprecated. Unless you are using an older OpenStack environment, it is
    recommended to use the [`openstack_networking_floatingip_v2`](networking_floatingip_v2.html)
    resource instead, which uses the OpenStack Networking API.
    """
    def __init__(__self__, __name__, __opts__=None, pool=None, region=None):
        """Create a FloatingIP resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if not pool:
            raise TypeError('Missing required property pool')
        elif not isinstance(pool, basestring):
            raise TypeError('Expected property pool to be a basestring')
        __self__.pool = pool
        """
        The name of the pool from which to obtain the floating
        IP. Changing this creates a new floating IP.
        """
        __props__['pool'] = pool

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Compute client.
        A Compute client is needed to create a floating IP that can be used with
        a compute instance. If omitted, the `region` argument of the provider
        is used. Changing this creates a new floating IP (which may or may not
        have a different address).
        """
        __props__['region'] = region

        __self__.address = pulumi.runtime.UNKNOWN
        """
        The actual floating IP address itself.
        """
        __self__.fixed_ip = pulumi.runtime.UNKNOWN
        """
        The fixed IP address corresponding to the floating IP.
        """
        __self__.instance_id = pulumi.runtime.UNKNOWN
        """
        UUID of the compute instance associated with the floating IP.
        """

        super(FloatingIP, __self__).__init__(
            'openstack:compute/floatingIP:FloatingIP',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'address' in outs:
            self.address = outs['address']
        if 'fixedIp' in outs:
            self.fixed_ip = outs['fixedIp']
        if 'instanceId' in outs:
            self.instance_id = outs['instanceId']
        if 'pool' in outs:
            self.pool = outs['pool']
        if 'region' in outs:
            self.region = outs['region']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Keypair(pulumi.CustomResource):
    """
    Manages a V2 keypair resource within OpenStack.
    
    ~> **Important Security Notice** The private key generated by this resource will
    be stored *unencrypted* in your Terraform state file. **Use of this resource
    for production deployments is *not* recommended**. Instead, generate
    a private key file outside of Terraform and distribute it securely
    to the system where Terraform will be run.
    """
    def __init__(__self__, __name__, __opts__=None, name=None, public_key=None, region=None, value_specs=None):
        """Create a Keypair resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        A unique name for the keypair. Changing this creates a new
        keypair.
        """
        __props__['name'] = name

        if public_key and not isinstance(public_key, basestring):
            raise TypeError('Expected property public_key to be a basestring')
        __self__.public_key = public_key
        """
        A pregenerated OpenSSH-formatted public key.
        Changing this creates a new keypair. If a public key is not specified, then
        a public/private key pair will be automatically generated. If a pair is
        created, then destroying this resource means you will lose access to that
        keypair forever.
        """
        __props__['publicKey'] = public_key

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Compute client.
        Keypairs are associated with accounts, but a Compute client is needed to
        create one. If omitted, the `region` argument of the provider is used.
        Changing this creates a new keypair.
        """
        __props__['region'] = region

        if value_specs and not isinstance(value_specs, dict):
            raise TypeError('Expected property value_specs to be a dict')
        __self__.value_specs = value_specs
        """
        Map of additional options.
        """
        __props__['valueSpecs'] = value_specs

        __self__.fingerprint = pulumi.runtime.UNKNOWN
        """
        The fingerprint of the public key.
        """
        __self__.private_key = pulumi.runtime.UNKNOWN
        """
        The generated private key when no public key is specified.
        """

        super(Keypair, __self__).__init__(
            'openstack:compute/keypair:Keypair',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'fingerprint' in outs:
            self.fingerprint = outs['fingerprint']
        if 'name' in outs:
            self.name = outs['name']
        if 'privateKey' in outs:
            self.private_key = outs['privateKey']
        if 'publicKey' in outs:
            self.public_key = outs['publicKey']
        if 'region' in outs:
            self.region = outs['region']
        if 'valueSpecs' in outs:
            self.value_specs = outs['valueSpecs']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Make subpackages available:
__all__ = ['blockstorage', 'compute', 'config', 'database', 'dns', 'firewall', 'identity', 'images', 'loadbalancer', 'networking', 'objectstorage', 'vpnaas']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Vip(pulumi.CustomResource):
    """
    Manages a V1 load balancer vip resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, address=None, admin_state_up=None, conn_limit=None, description=None, floating_ip=None, name=None, persistence=None, pool_id=None, port=None, protocol=None, region=None, subnet_id=None, tenant_id=None):
        """Create a Vip resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if address and not isinstance(address, basestring):
            raise TypeError('Expected property address to be a basestring')
        __self__.address = address
        """
        The IP address of the vip. Changing this creates a new
        vip.
        """
        __props__['address'] = address

        if admin_state_up and not isinstance(admin_state_up, bool):
            raise TypeError('Expected property admin_state_up to be a bool')
        __self__.admin_state_up = admin_state_up
        """
        The administrative state of the vip.
        Acceptable values are "true" and "false". Changing this value updates the
        state of the existing vip.
        """
        __props__['adminStateUp'] = admin_state_up

        if conn_limit and not isinstance(conn_limit, int):
            raise TypeError('Expected property conn_limit to be a int')
        __self__.conn_limit = conn_limit
        """
        The maximum number of connections allowed for the
        vip. Default is -1, meaning no limit. Changing this updates the conn_limit
        of the existing vip.
        """
        __props__['connLimit'] = conn_limit

        if description and not isinstance(description, basestring):
            raise TypeError('Expected property description to be a basestring')
        __self__.description = description
        """
        Human-readable description for the vip. Changing
        this updates the description of the existing vip.
        """
        __props__['description'] = description

        if floating_ip and not isinstance(floating_ip, basestring):
            raise TypeError('Expected property floating_ip to be a basestring')
        __self__.floating_ip = floating_ip
        """
        A *Networking* Floating IP that will be associated
        with the vip. The Floating IP must be provisioned already.
        """
        __props__['floatingIp'] = floating_ip

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        The name of the vip. Changing this updates the name of
        the existing vip.
        """
        __props__['name'] = name

        if persistence and not isinstance(persistence, dict):
            raise TypeError('Expected property persistence to be a dict')
        __self__.persistence = persistence
        """
        Omit this field to prevent session persistence.
        The persistence object structure is documented below. Changing this updates
        the persistence of the existing vip.
        """
        __props__['persistence'] = persistence

        if not pool_id:
            raise TypeError('Missing required property pool_id')
        elif not isinstance(pool_id, basestring):
            raise TypeError('Expected property pool_id to be a basestring')
        __self__.pool_id = pool_id
        """
        The ID of the pool with which the vip is associated.
        Changing this updates the pool_id of the existing vip.
        """
        __props__['poolId'] = pool_id

        if not port:
            raise TypeError('Missing required property port')
        elif not isinstance(port, int):
            raise TypeError('Expected property port to be a int')
        __self__.port = port
        """
        The port on which to listen for client traffic. Changing
        this creates a new vip.
        """
        __props__['port'] = port

        if not protocol:
            raise TypeError('Missing required property protocol')
        elif not isinstance(protocol, basestring):
            raise TypeError('Expected property protocol to be a basestring')
        __self__.protocol = protocol
        """
        The protocol - can be either 'TCP, 'HTTP', or
        HTTPS'. Changing this creates a new vip.
        """
        __props__['protocol'] = protocol

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a VIP. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        VIP.
        """
        __props__['region'] = region

        if not subnet_id:
            raise TypeError('Missing required property subnet_id')
        elif not isinstance(subnet_id, basestring):
            raise TypeError('Expected property subnet_id to be a basestring')
        __self__.subnet_id = subnet_id
        """
        The network on which to allocate the vip's address. A
        tenant can only create vips on networks authorized by policy (e.g. networks
        that belong to them or networks that are shared). Changing this creates a
        new vip.
        """
        __props__['subnetId'] = subnet_id

        if tenant_id and not isinstance(tenant_id, basestring):
            raise TypeError('Expected property tenant_id to be a basestring')
        __self__.tenant_id = tenant_id
        """
        The owner of the vip. Required if admin wants to
        create a vip member for another tenant. Changing this creates a new vip.
        """
        __props__['tenantId'] = tenant_id

        __self__.port_id = pulumi.runtime.UNKNOWN
        """
        Port UUID for this VIP at associated floating IP (if any).
        """

        super(Vip, __self__).__init__(
            'openstack:loadbalancer/vip:Vip',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'address' in outs:
            self.address = outs['address']
        if 'adminStateUp' in outs:
            self.admin_state_up = outs['adminStateUp']
        if 'connLimit' in outs:
            self.conn_limit = outs['connLimit']
        if 'description' in outs:
            self.description = outs['description']
        if 'floatingIp' in outs:
            self.floating_ip = outs['floatingIp']
        if 'name' in outs:
            self.name = outs['name']
        if 'persistence' in outs:
            self.persistence = outs['persistence']
        if 'poolId' in outs:
            self.pool_id = outs['poolId']
        if 'port' in outs:
            self.port = outs['port']
        if 'portId' in outs:
            self.port_id = outs['portId']
        if 'protocol' in outs:
            self.protocol = outs['protocol']
        if 'region' in outs:
            self.region = outs['region']
        if 'subnetId' in outs:
            self.subnet_id = outs['subnetId']
        if 'tenantId' in outs:
            self.tenant_id = outs['tenantId']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Listener(pulumi.CustomResource):
    """
    Manages a V2 listener resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, admin_state_up=None, connection_limit=None, default_pool_id=None, default_tls_container_ref=None, description=None, loadbalancer_id=None, name=None, protocol=None, protocol_port=None, region=None, sni_container_refs=None, tenant_id=None):
        """Create a Listener resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if admin_state_up and not isinstance(admin_state_up, bool):
            raise TypeError('Expected property admin_state_up to be a bool')
        __self__.admin_state_up = admin_state_up
        """
        The administrative state of the Listener.
        A valid value is true (UP) or false (DOWN).
        """
        __props__['adminStateUp'] = admin_state_up

        if connection_limit and not isinstance(connection_limit, int):
            raise TypeError('Expected property connection_limit to be a int')
        __self__.connection_limit = connection_limit
        """
        The maximum number of connections allowed
        for the Listener.
        """
        __props__['connectionLimit'] = connection_limit

        if default_pool_id and not isinstance(default_pool_id, basestring):
            raise TypeError('Expected property default_pool_id to be a basestring')
        __self__.default_pool_id = default_pool_id
        """
        The ID of the default pool with which the
        Listener is associated. Changing this creates a new Listener.
        """
        __props__['defaultPoolId'] = default_pool_id

        if default_tls_container_ref and not isinstance(default_tls_container_ref, basestring):
            raise TypeError('Expected property default_tls_container_ref to be a basestring')
        __self__.default_tls_container_ref = default_tls_container_ref
        """
        A reference to a Barbican Secrets
        container which stores TLS information. This is required if the protocol
        is `TERMINATED_HTTPS`. See
        [here](https://wiki.openstack.org/wiki/Network/LBaaS/docs/how-to-create-tls-loadbalancer)
        for more information.
        """
        __props__['defaultTlsContainerRef'] = default_tls_container_ref

        if description and not isinstance(description, basestring):
            raise TypeError('Expected property description to be a basestring')
        __self__.description = description
        """
        Human-readable description for the Listener.
        """
        __props__['description'] = description

        if not loadbalancer_id:
            raise TypeError('Missing required property loadbalancer_id')
        elif not isinstance(loadbalancer_id, basestring):
            raise TypeError('Expected property loadbalancer_id to be a basestring')
        __self__.loadbalancer_id = loadbalancer_id
        """
        The load balancer on which to provision this
        Listener. Changing this creates a new Listener.
        """
        __props__['loadbalancerId'] = loadbalancer_id

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        Human-readable name for the Listener. Does not have
        to be unique.
        """
        __props__['name'] = name

        if not protocol:
            raise TypeError('Missing required property protocol')
        elif not isinstance(protocol, basestring):
            raise TypeError('Expected property protocol to be a basestring')
        __self__.protocol = protocol
        """
        The protocol - can either be TCP, HTTP, HTTPS or TERMINATED_HTTPS.
        Changing this creates a new Listener.
        """
        __props__['protocol'] = protocol

        if not protocol_port:
            raise TypeError('Missing required property protocol_port')
        elif not isinstance(protocol_port, int):
            raise TypeError('Expected property protocol_port to be a int')
        __self__.protocol_port = protocol_port
        """
        The port on which to listen for client traffic.
        Changing this creates a new Listener.
        """
        __props__['protocolPort'] = protocol_port

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create an . If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        Listener.
        """
        __props__['region'] = region

        if sni_container_refs and not isinstance(sni_container_refs, list):
            raise TypeError('Expected property sni_container_refs to be a list')
        __self__.sni_container_refs = sni_container_refs
        """
        A list of references to Barbican Secrets
        containers which store SNI information. See
        [here](https://wiki.openstack.org/wiki/Network/LBaaS/docs/how-to-create-tls-loadbalancer)
        for more information.
        """
        __props__['sniContainerRefs'] = sni_container_refs

        if tenant_id and not isinstance(tenant_id, basestring):
            raise TypeError('Expected property tenant_id to be a basestring')
        __self__.tenant_id = tenant_id
        """
        Required for admins. The UUID of the tenant who owns
        the Listener.  Only administrative users can specify a tenant UUID
        other than their own. Changing this creates a new Listener.
        """
        __props__['tenantId'] = tenant_id

        super(Listener, __self__).__init__(
            'openstack:loadbalancer/listener:Listener',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'adminStateUp' in outs:
            self.admin_state_up = outs['adminStateUp']
        if 'connectionLimit' in outs:
            self.connection_limit = outs['connectionLimit']
        if 'defaultPoolId' in outs:
            self.default_pool_id = outs['defaultPoolId']
        if 'defaultTlsContainerRef' in outs:
            self.default_tls_container_ref = outs['defaultTlsContainerRef']
        if 'description' in outs:
            self.description = outs['description']
        if 'loadbalancerId' in outs:
            self.loadbalancer_id = outs['loadbalancerId']
        if 'name' in outs:
            self.name = outs['name']
        if 'protocol' in outs:
            self.protocol = outs['protocol']
        if 'protocolPort' in outs:
            self.protocol_port = outs['protocolPort']
        if 'region' in outs:
            self.region = outs['region']
        if 'sniContainerRefs' in outs:
            self.sni_container_refs = outs['sniContainerRefs']
        if 'tenantId' in outs:
            self.tenant_id = outs['tenantId']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class IkePolicy(pulumi.CustomResource):
    """
    Manages a V2 Neutron IKE policy resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, auth_algorithm=None, description=None, encryption_algorithm=None, ike_version=None, lifetimes=None, name=None, pfs=None, phase1_negotiation_mode=None, region=None, tenant_id=None, value_specs=None):
        """Create a IkePolicy resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if auth_algorithm and not isinstance(auth_algorithm, basestring):
            raise TypeError('Expected property auth_algorithm to be a basestring')
        __self__.auth_algorithm = auth_algorithm
        """
        The authentication hash algorithm. Valid values are sha1, sha256, sha384, sha512.
        Default is sha1. Changing this updates the algorithm of the existing policy.
        """
        __props__['authAlgorithm'] = auth_algorithm

        if description and not isinstance(description, basestring):
            raise TypeError('Expected property description to be a basestring')
        __self__.description = description
        """
        The human-readable description for the policy.
        Changing this updates the description of the existing policy.
        """
        __props__['description'] = description

        if encryption_algorithm and not isinstance(encryption_algorithm, basestring):
            raise TypeError('Expected property encryption_algorithm to be a basestring')
        __self__.encryption_algorithm = encryption_algorithm
        """
        The encryption algorithm. Valid values are 3des, aes-128, aes-192 and so on.
        The default value is aes-128. Changing this updates the existing policy.
        """
        __props__['encryptionAlgorithm'] = encryption_algorithm

        if ike_version and not isinstance(ike_version, basestring):
            raise TypeError('Expected property ike_version to be a basestring')
        __self__.ike_version = ike_version
        """
        The IKE mode. A valid value is v1 or v2. Default is v1.
        Changing this updates the existing policy.
        """
        __props__['ikeVersion'] = ike_version

        if lifetimes and not isinstance(lifetimes, list):
            raise TypeError('Expected property lifetimes to be a list')
        __self__.lifetimes = lifetimes
        """
        The lifetime of the security association. Consists of Unit and Value.
        - `unit` - (Optional) The units for the lifetime of the security association. Can be either seconds or kilobytes.
        Default is seconds.
        - `value` - (Optional) The value for the lifetime of the security association. Must be a positive integer.
        Default is 3600.
        """
        __props__['lifetimes'] = lifetimes

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        The name of the policy. Changing this updates the name of
        the existing policy.
        """
        __props__['name'] = name

        if pfs and not isinstance(pfs, basestring):
            raise TypeError('Expected property pfs to be a basestring')
        __self__.pfs = pfs
        """
        The perfect forward secrecy mode. Valid values are Group2, Group5 and Group14. Default is Group5.
        Changing this updates the existing policy.
        """
        __props__['pfs'] = pfs

        if phase1_negotiation_mode and not isinstance(phase1_negotiation_mode, basestring):
            raise TypeError('Expected property phase1_negotiation_mode to be a basestring')
        __self__.phase1_negotiation_mode = phase1_negotiation_mode
        """
        The IKE mode. A valid value is main, which is the default.
        Changing this updates the existing policy.
        """
        __props__['phase1NegotiationMode'] = phase1_negotiation_mode

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a VPN service. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        service.
        """
        __props__['region'] = region

        if tenant_id and not isinstance(tenant_id, basestring):
            raise TypeError('Expected property tenant_id to be a basestring')
        __self__.tenant_id = tenant_id
        """
        The owner of the policy. Required if admin wants to
        create a service for another policy. Changing this creates a new policy.
        """
        __props__['tenantId'] = tenant_id

        if value_specs and not isinstance(value_specs, dict):
            raise TypeError('Expected property value_specs to be a dict')
        __self__.value_specs = value_specs
        """
        Map of additional options.
        """
        __props__['valueSpecs'] = value_specs

        super(IkePolicy, __self__).__init__(
            'openstack:vpnaas/ikePolicy:IkePolicy',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'authAlgorithm' in outs:
            self.auth_algorithm = outs['authAlgorithm']
        if 'description' in outs:
            self.description = outs['description']
        if 'encryptionAlgorithm' in outs:
            self.encryption_algorithm = outs['encryptionAlgorithm']
        if 'ikeVersion' in outs:
            self.ike_version = outs['ikeVersion']
        if 'lifetimes' in outs:
            self.lifetimes = outs['lifetimes']
        if 'name' in outs:
            self.name = outs['name']
        if 'pfs' in outs:
            self.pfs = outs['pfs']
        if 'phase1NegotiationMode' in outs:
            self.phase1_negotiation_mode = outs['phase1NegotiationMode']
        if 'region' in outs:
            self.region = outs['region']
        if 'tenantId' in outs:
            self.tenant_id = outs['tenantId']
        if 'valueSpecs' in outs:
            self.value_specs = outs['valueSpecs']



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class GetKeypairResult(object):
    """
    A collection of values returned by getKeypair.
    """
    def __init__(__self__, public_key=None, region=None):
        if public_key and not isinstance(public_key, basestring):
            raise TypeError('Expected argument public_key to be a basestring')
        __self__.public_key = public_key
        """
        The OpenSSH-formatted public key of the keypair.
        """
        if region and not isinstance(region, basestring):
            raise TypeError('Expected argument region to be a basestring')
        __self__.region = region
        """
        See Argument Reference above.
        """

def get_keypair(name=None, region=None):
    """
    Use this data source to get the ID and public key of an OpenStack keypair.
    """
    __args__ = dict()

    __args__['name'] = name
    __args__['region'] = region
    __ret__ = pulumi.runtime.invoke('openstack:compute/getKeypair:getKeypair', __args__)

    return GetKeypairResult(
        public_key=__ret__.get('publicKey'),
        region=__ret__.get('region'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime

class Subnet(pulumi.CustomResource):
    """
    Manages a V2 Neutron subnet resource within OpenStack.
    """
    def __init__(__self__, __name__, __opts__=None, allocation_pools=None, cidr=None, dns_nameservers=None, enable_dhcp=None, gateway_ip=None, host_routes=None, ip_version=None, ipv6_address_mode=None, ipv6_ra_mode=None, name=None, network_id=None, no_gateway=None, region=None, subnetpool_id=None, tenant_id=None, value_specs=None):
        """Create a Subnet resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, basestring):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if allocation_pools and not isinstance(allocation_pools, list):
            raise TypeError('Expected property allocation_pools to be a list')
        __self__.allocation_pools = allocation_pools
        """
        An array of sub-ranges of CIDR available for
        dynamic allocation to ports. The allocation_pool object structure is
        documented below. Changing this creates a new subnet.
        """
        __props__['allocationPools'] = allocation_pools

        if cidr and not isinstance(cidr, basestring):
            raise TypeError('Expected property cidr to be a basestring')
        __self__.cidr = cidr
        """
        CIDR representing IP range for this subnet, based on IP
        version. Changing this creates a new subnet.
        """
        __props__['cidr'] = cidr

        if dns_nameservers and not isinstance(dns_nameservers, list):
            raise TypeError('Expected property dns_nameservers to be a list')
        __self__.dns_nameservers = dns_nameservers
        """
        An array of DNS name server names used by hosts
        in this subnet. Changing this updates the DNS name servers for the existing
        subnet.
        """
        __props__['dnsNameservers'] = dns_nameservers

        if enable_dhcp and not isinstance(enable_dhcp, bool):
            raise TypeError('Expected property enable_dhcp to be a bool')
        __self__.enable_dhcp = enable_dhcp
        """
        The administrative state of the network.
        Acceptable values are "true" and "false". Changing this value enables or
        disables the DHCP capabilities of the existing subnet. Defaults to true.
        """
        __props__['enableDhcp'] = enable_dhcp

        if gateway_ip and not isinstance(gateway_ip, basestring):
            raise TypeError('Expected property gateway_ip to be a basestring')
        __self__.gateway_ip = gateway_ip
        """
        Default gateway used by devices in this subnet.
        Leaving this blank and not setting `no_gateway` will cause a default
        gateway of `.1` to be used. Changing this updates the gateway IP of the
        existing subnet.
        """
        __props__['gatewayIp'] = gateway_ip

        if host_routes and not isinstance(host_routes, list):
            raise TypeError('Expected property host_routes to be a list')
        __self__.host_routes = host_routes
        """
        An array of routes that should be used by devices
        with IPs from this subnet (not including local subnet route). The host_route
        object structure is documented below. Changing this updates the host routes
        for the existing subnet.
        """
        __props__['hostRoutes'] = host_routes

        if ip_version and not isinstance(ip_version, int):
            raise TypeError('Expected property ip_version to be a int')
        __self__.ip_version = ip_version
        """
        IP version, either 4 (default) or 6. Changing this creates a
        new subnet.
        """
        __props__['ipVersion'] = ip_version

        if ipv6_address_mode and not isinstance(ipv6_address_mode, basestring):
            raise TypeError('Expected property ipv6_address_mode to be a basestring')
        __self__.ipv6_address_mode = ipv6_address_mode
        """
        The IPv6 address mode. Valid values are
        `dhcpv6-stateful`, `dhcpv6-stateless`, or `slaac`.
        """
        __props__['ipv6AddressMode'] = ipv6_address_mode

        if ipv6_ra_mode and not isinstance(ipv6_ra_mode, basestring):
            raise TypeError('Expected property ipv6_ra_mode to be a basestring')
        __self__.ipv6_ra_mode = ipv6_ra_mode
        """
        The IPv6 Router Advertisement mode. Valid values
        are `dhcpv6-stateful`, `dhcpv6-stateless`, or `slaac`.
        """
        __props__['ipv6RaMode'] = ipv6_ra_mode

        if name and not isinstance(name, basestring):
            raise TypeError('Expected property name to be a basestring')
        __self__.name = name
        """
        The name of the subnet. Changing this updates the name of
        the existing subnet.
        """
        __props__['name'] = name

        if not network_id:
            raise TypeError('Missing required property network_id')
        elif not isinstance(network_id, basestring):
            raise TypeError('Expected property network_id to be a basestring')
        __self__.network_id = network_id
        """
        The UUID of the parent network. Changing this
        creates a new subnet.
        """
        __props__['networkId'] = network_id

        if no_gateway and not isinstance(no_gateway, bool):
            raise TypeError('Expected property no_gateway to be a bool')
        __self__.no_gateway = no_gateway
        """
        Do not set a gateway IP on this subnet. Changing
        this removes or adds a default gateway IP of the existing subnet.
        """
        __props__['noGateway'] = no_gateway

        if region and not isinstance(region, basestring):
            raise TypeError('Expected property region to be a basestring')
        __self__.region = region
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a Neutron subnet. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        subnet.
        """
        __props__['region'] = region

        if subnetpool_id and not isinstance(subnetpool_id, basestring):
            raise TypeError('Expected property subnetpool_id to be a basestring')
        __self__.subnetpool_id = subnetpool_id
        """
        The ID of the subnetpool associated with the subnet.
        """
        __props__['subnetpoolId'] = subnetpool_id

        if tenant_id and not isinstance(tenant_id, basestring):
            raise TypeError('Expected property tenant_id to be a basestring')
        __self__.tenant_id = tenant_id
        """
        The owner of the subnet. Required if admin wants to
        create a subnet for another tenant. Changing this creates a new subnet.
        """
        __props__['tenantId'] = tenant_id

        if value_specs and not isinstance(value_specs, dict):
            raise TypeError('Expected property value_specs to be a dict')
        __self__.value_specs = value_specs
        """
        Map of additional options.
        """
        __props__['valueSpecs'] = value_specs

        super(Subnet, __self__).__init__(
            'openstack:networking/subnet:Subnet',
            __name__,
            __props__,
            __opts__)

    def set_outputs(self, outs):
        if 'allocationPools' in outs:
            self.allocation_pools = outs['allocationPools']
        if 'cidr' in outs:
            self.cidr = outs['cidr']
        if 'dnsNameservers' in outs:
            self.dns_nameservers = outs['dnsNameservers']
        if 'enableDhcp' in outs:
            self.enable_dhcp = outs['enableDhcp']
        if 'gatewayIp' in outs:
            self.gateway_ip = outs['gatewayIp']
        if 'hostRoutes' in outs:
            self.host_routes = outs['hostRoutes']
        if 'ipVersion' in outs:
            self.ip_version = outs['ipVersion']
        if 'ipv6AddressMode' in outs:
            self.ipv6_address_mode = outs['ipv6AddressMode']
        if 'ipv6RaMode' in outs:
            self.ipv6_ra_mode = outs['ipv6RaMode']
        if 'name' in outs:
            self.name = outs['name']
        if 'networkId' in outs:
            self.network_id = outs['networkId']
        if 'noGateway' in outs:
            self.no_gateway = outs['noGateway']
        if 'region' in outs:
            self.region = outs['region']
        if 'subnetpoolId' in outs:
            self.subnetpool_id = outs['subnetpoolId']
        if 'tenantId' in outs:
            self.tenant_id = outs['tenantId']
        if 'valueSpecs' in outs:
            self.value_specs = outs['valueSpecs']
